@@ -9,7 +9,7 @@ use feature ":5.10";
 use Config;
 use File::Spec::Functions qw(catdir rel2abs splitpath);
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use constant DFLT_TOCOPY_SECTION  => "__TOCOPY__";
 
@@ -17,7 +17,9 @@ use constant FLD_KEY_PREFIX => __PACKAGE__ . ' __ ';
 
 use constant {EXPANDED          => FLD_KEY_PREFIX . 'EXPANDED',
 
+              CMNT_VL           => FLD_KEY_PREFIX . 'CMNT_VL',
               TOCOPY_SECTION    => FLD_KEY_PREFIX . 'TOCOPY_SECTION',
+              CURR_TOCP_SECTION => FLD_KEY_PREFIX . 'CURR_TOCP_SECTION',
               TOCOPY_VARS       => FLD_KEY_PREFIX . 'TOCOPY_VARS',
               NOT_TOCOPY        => FLD_KEY_PREFIX . 'NOT_TOCOPY',
               SECTIONS          => FLD_KEY_PREFIX . 'SECTIONS',
@@ -26,11 +28,13 @@ use constant {EXPANDED          => FLD_KEY_PREFIX . 'EXPANDED',
               VARIABLES         => FLD_KEY_PREFIX . 'VARIABLES',
               GLOBAL_VARS       => FLD_KEY_PREFIX . 'GLOBAL_VARS',
               VREF_RE           => FLD_KEY_PREFIX . 'VREF_RE',
+              SEPARATOR         => FLD_KEY_PREFIX . 'SEPARATOR',
               BACKUP            => FLD_KEY_PREFIX . 'BACKUP',
              };
 
-my %Globals = ('=:'  => catdir("", "",),
-               '=::' => $Config{path_sep});
+my %Globals = ('=:'       => catdir("", "",),
+               '=::'      => $Config{path_sep},
+               '=VERSION' => $VERSION);
 
 
 # Match punctuation chars, but not the underscores.
@@ -81,21 +85,23 @@ my $_check_not_tocopy = sub {
 sub new {
   my ($class, %args) = @_;
   state $allowed_keys = {map {$_ => undef} qw(tocopy_section tocopy_vars not_tocopy
-                                              separator)};
+                                              separator cmnt_vl)};
   _check_args(\%args, $allowed_keys);
   my $self = {};
   croak("'tocopy_section': must not be a reference") if ref($args{tocopy_section});
   if (exists($args{separator})) {
-    state $allowed_sep_chars = "!#%&',./:~";
+    state $allowed_sep_chars = "#!%&',./:~\\";
     my $sep = $args{separator};
     croak("'separator': unexpected ref type, must be a scalar") if ref($sep);
     croak("'separator': invalid value. Allowed chars: $allowed_sep_chars")
-      if $sep !~ m{^[$allowed_sep_chars]+$};
+      if $sep !~ m{^[\Q$allowed_sep_chars\E]+$};
+    $self->{+SEPARATOR} = $sep;
     $self->{+VREF_RE} = qr/^(.*?)(?:\Q$sep\E)(.*)$/;
   }
   else {
     $self->{+VREF_RE} = qr/^\[\s*(.*?)\s*\](.*)$/;
   }
+  $self->{+CMNT_VL} = $args{cmnt_vl};
   $self->{+TOCOPY_SECTION} = $args{tocopy_section} // DFLT_TOCOPY_SECTION;
   $self->$_check_tocopy_vars($args{tocopy_vars}, 1) if exists($args{tocopy_vars});
   $self->$_check_not_tocopy($args{not_tocopy},   1) if exists($args{not_tocopy});
@@ -138,6 +144,7 @@ my $_parse_ini = sub {
     $src = [do { local (*ARGV); @ARGV = ($src_name); <> }];
   }
   my $curr_section;
+  my $cmnt_vl     = $self->{+CMNT_VL};
   my $sections    = $self->{+SECTIONS};
   my $sections_h  = $self->{+SECTIONS_H};
   my $expanded    = $self->{+EXPANDED};
@@ -185,6 +192,7 @@ my $_parse_ini = sub {
     }
 
     # var = val
+    $line =~ s/\s+;.*$// if $cmnt_vl;
     $set_curr_section->($tocopy_sec) if !defined($curr_section);
     $line =~ /^(.*?)\s*($Modifier_Char*?)=(?:\s*)(.*)/ or
       $_fatal->("neither section header nor key definition");
@@ -256,6 +264,7 @@ sub parse_ini {
   else {
     $tocopy_section = $self->{+TOCOPY_SECTION};
   }
+  $self->{+CURR_TOCP_SECTION} = $tocopy_section;
   if ($tocopy_vars) {
     $backup->{tocopy_vars} = $self->{+TOCOPY_VARS};
     $self->$_check_tocopy_vars($tocopy_vars, 1);
@@ -334,17 +343,17 @@ sub parse_ini {
 }
 
 
+sub current_tocopy_section {$_[0]->{+CURR_TOCP_SECTION}}
 sub sections        { defined($_[0]->{+SECTIONS})   ? [@{$_[0]->{+SECTIONS}}]     : undef}
-
 sub sections_h      { defined($_[0]->{+SECTIONS_H}) ? +{ %{$_[0]->{+SECTIONS_H}} } : undef }
+sub separator       {$_[0]->{+SEPARATOR}}
+sub src_name        {$_[0]->{+SRC_NAME}}
+sub tocopy_section  {$_[0]->{+TOCOPY_SECTION}}
 
 sub variables       { my $vars = $_[0]->{+VARIABLES} // return undef;
                       return  {map {$_ => {%{$vars->{$_}}}} keys(%$vars)};
                     }
 
-sub src_name        {$_[0]->{+SRC_NAME}}
-sub tocopy_section  {$_[0]->{+TOCOPY_SECTION}}
-
 
 $_look_up = sub {
   my ($self, $curr_sect, $variable) = @_;
@@ -463,7 +472,7 @@ Config::INI::RefVars - INI file reader, allows the referencing of INI and enviro
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =head1 SYNOPSIS
 
@@ -866,6 +875,16 @@ unwanted variable expansion:
 With these settings, C<x> has the value C<Hello!>, but C<y> has the value
 C<$(var)>.
 
+=head3 Other Variables
+
+=over
+
+=item C<=VERSION>
+
+Version of the C<Config::INI::RefVars> module.
+
+=back
+
 
 =head3 Custom predefined Variables
 
@@ -1045,6 +1064,38 @@ The constructor takes the following optional named arguments:
 
 =over
 
+=item C<not_tocopy>
+
+Optional, a reference to a hash or an array of strings. The hash keys or array
+entries specify a list of variables that should not be copied from the
+I<tocopy> section to the other sections. It does not matter whether these
+variables actually occur in the I<tocopy> section or not.
+
+Default is C<undef>.
+
+=item C<separator>
+
+Optional, a string. If specified, an alternative notation can be used for
+referencing variables in another section. Example:
+
+   my $obj = Config::INI::RefVars->new(separator => '::');
+
+Then you can write:
+
+    [A]
+    y=27
+
+    [B]
+    a var=$(A::y)
+
+This gives the variable C<a var> the value C<27>.
+
+The following characters are permitted for C<separator>:
+
+   #!%&',./:~\
+
+See also the accessor method of the same name.
+
 =item C<tocopy_section>
 
 Optional, a string. Specifies a different name for the I<tocopy>
@@ -1061,44 +1112,40 @@ Keys with C<=> or C<;> as the first character are not permitted.
 
 Default is C<undef>.
 
-=item C<not_tocopy>
+=item C<cmnt_vl>
 
-Optional, a reference to a hash or an array of strings. The hash keys or array
-entries specify a list of variables that should not be copied from the
-I<tocopy> section to the other sections. It does not matter whether these
-variables actually occur in the I<tocopy> section or not.
+Optional, a Boolean value. If this value is set to I<true>, comments are
+permitted in variable lines. The comment character is a semicolon preceded by
+one or more spaces.
 
-Default is C<undef>.
+Example:
 
-=item C<separator>
+   [section]
+   var 1=val 1 ; comment
+   var 2=val 2  ; ;  ; comment
+   var 3=val 3; no comment
+   var 4=val 4 $(); no comment
 
-Optional, a character string. If specified, an alternative notation can be
-used for referencing variables in another section. Example:
+After parsing, the C<variables> method returns:
 
-   my $obj = Config::INI::RefVars->new(separator => '::');
+   section => {'var 1' => 'val 1',
+               'var 2' => 'val 2',
+               'var 3' => 'val 3; no comment',
+               'var 4' => 'val 4 ; no comment',
+              }
 
-Then you can write:
-
-    [A]
-    y=27
-    
-    [B]
-    a var=$(A::y)
-
-This gives the variable C<a var> the value C<27>.
-
-The following characters are permitted for C<separator>:
-
-   !#%&',./:~
+Default is I<false> (C<undef>).
 
 =back
 
 
+=head3 current_tocopy_section
 
-=head3 tocopy_section
+Returns the name of the section I<tocopy> that was used the last time
+C<parse_ini> was called. Please note that the section does not have to be
+present in the data.
 
-Returns the name of the I<tocopy> section that will be used as the default for
-the next call to C<parse_ini>.
+See also method C<tocopy_section>.
 
 
 =head3 parse_ini
@@ -1166,6 +1213,13 @@ Returns a reference to a hash whose keys are the section names from the INI
 source, the values are the corresponding indices in the array returned by
 C<sections>.
 
+
+=head3 separator
+
+Returns the value that was passed to the constructor via the argument of the
+same name, or C<undef> .
+
+
 =head3 src_name
 
 Returns the name of the INI source (file name that you have passed to
@@ -1173,6 +1227,15 @@ C<parse_ini> via the argument C<src>, or the one that you have passed via the
 argument C<src_name>, or "C<INI data>", see section L</"Variables in relation
 to the source">.
 
+
+=head3 tocopy_section
+
+Returns the name of the I<tocopy> section that will be used as the default for
+the next call to C<parse_ini>.
+
+See also method C<current_tocopy_section>.
+
+
 =head3 variables
 
 Returns a reference to a hash of hashes. The keys are the section names, each
@@ -1181,6 +1244,51 @@ variable value). By default, variables with a C<=> in their name are not
 included; this can be changed with the C<cleanup> argument.
 
 
+=head2 EXAMPLES
+
+You can parse INI files as described here L<$(section\name) syntax for INI
+file
+variables|https://www.dhcpserver.de/cms/ini_file_reference/special/sectionname-syntax-for-ini-file-variables/>
+as follows:
+
+   my $obj = Config::INI::RefVars->new(separator      => "\\",
+                                       cmnt_vl        => 1,
+                                       tocopy_section => 'Settings');
+   my $src = <<'EOT';
+     [Settings]
+     BaseDir="d:\dhcpsrv" ; dhcpsrv.exe resides here
+     IPBIND_1=192.168.17.2
+     IPPOOL_1=$(Settings\IPBIND_1)-50
+     AssociateBindsToPools=1
+     Trace=1
+     TraceFile="$(BaseDir)\dhcptrc.txt" ; trace file
+
+     [DNS-Settings]
+     EnableDNS=1
+
+     [General]
+     SUBNETMASK=255.255.255.0
+     DNS_1=$(IPBIND_1)
+
+     [TFTP-Settings]
+     EnableTFTP=1
+     Root="$(BaseDir)\wwwroot" ; use wwwroot for http and tftp
+
+     [HTTP-Settings]
+     EnableHTTP=1
+     Root="$(BaseDir)\wwwroot" ; use wwwroot for http and tftp
+   EOT
+   $obj->parse_ini(src => $src);
+
+=head1 SEE ALSO
+
+L<$(section\name) syntax for INI file variables|https://www.dhcpserver.de/cms/ini_file_reference/special/sectionname-syntax-for-ini-file-variables/>
+
+L<Config::INI>,
+L<Config::INI::Tiny>,
+L<Config::IniFiles>
+
+
 =head1 AUTHOR
 
 Abdul al Hazred, C<< <451 at gmx.eu> >>
